@@ -1,12 +1,13 @@
 from dotenv import find_dotenv, load_dotenv
-from init import init
 from openai import OpenAI
-from utils.with_root_span import with_langtrace_root_span
 
+from langtrace_python_sdk import langtrace
+from langtrace_python_sdk.utils.with_root_span import with_langtrace_root_span
 
 _ = load_dotenv(find_dotenv())
 
-init()
+langtrace.init(batch=True, log_spans_to_console=True,
+               write_to_remote_url=False)
 
 client = OpenAI()
 
